# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-03 11:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('seo', '0002_model_translation'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site'),
        ),
        migrations.AlterField(
            model_name='pagemeta',
            name='url',
            field=models.CharField(db_index=True, max_length=255, verbose_name='URL'),
        ),
        migrations.AlterUniqueTogether(
            name='pagemeta',
            unique_together=set([('site', 'url')]),
        ),
    ]
